==> fbsdmon-0.93.tar.gz: fbsdmon-0.93/src/json.c <==
#include <stdlib.h>
#include <string.h>
#include <jansson.h>

#include "info.h"
#include "uuid.h"


#define ENC_FLAGS (JSON_INDENT(4) | JSON_PRESERVE_ORDER)

static json_t *root = NULL;
static json_t *sys = NULL;
static json_t *pkg = NULL;


extern void set_sys_info(char *system, char *ver, char *arch)
{
    if(! sys) sys = json_object();

    json_object_set_new(sys, "system", json_string(system));
    json_object_set_new(sys, "version", json_string(ver));
    json_object_set_new(sys, "machine", json_string(arch));
}

extern void set_pkg_info(char *cat, char *name)
{
    json_t *obj = json_object();

    json_object_set_new(obj, "cat", json_string(cat));
    json_object_set_new(obj, "port", json_string(name));

    if(! pkg) pkg = json_array();
    json_array_append_new(pkg, obj);
}

extern void json_flush()
{
    if(root) {
        json_object_clear(root);
        json_decref(root);
    } else {
        if(sys) {
            json_object_clear(sys);
            json_decref(sys);
        }

        if(pkg) {
            json_array_clear(pkg);
            json_decref(pkg);
        }
    }
}

extern char *get_json_sys()
{
    if(NULL == sys) build_sys_info();
    return json_dumps(sys, ENC_FLAGS);
}

extern char *get_json_pkg()
{
    if(NULL == pkg) build_pkg_info();
    return json_dumps(pkg, ENC_FLAGS);
}

extern char *get_json_root()
{
    if(! root)
    {
        root = json_object();

        char *myid = uuid();
        json_object_set_new(root, "uuid", json_string(myid));
        free(myid);

        free(get_json_sys());
        free(get_json_pkg());

        json_object_set_new(root, "sys", sys);
        json_object_set_new(root, "pkg", pkg);
    }

    return json_dumps(root, ENC_FLAGS);
}

==> fbsdmon-1.00.tar.gz: fbsdmon-1.00/src/json.c <==
#include <stdlib.h>
#include <string.h>
#include <jansson.h>

#include "json.h"
#include "info.h"
#include "uuid.h"


#define ENC_FLAGS (JSON_INDENT(4) | JSON_PRESERVE_ORDER)

static json_t *root = NULL;
static json_t *sys = NULL;
static json_t *pkg = NULL;


extern void set_sys_info(struct sys_info info)
{
    if(! sys) sys = json_object();

    json_object_set_new(sys, "system", json_string(info.system));
    json_object_set_new(sys, "version", json_string(info.version));
    json_object_set_new(sys, "machine", json_string(info.machine));
}

extern void set_pkg_info(char *cat, char *name)
{
    json_t *obj = json_object();

    json_object_set_new(obj, "cat", json_string(cat));
    json_object_set_new(obj, "port", json_string(name));

    if(! pkg) pkg = json_array();
    json_array_append_new(pkg, obj);
}

extern void json_flush()
{
    if(root) {
        json_object_clear(root);
        json_decref(root);
    } else {
        if(sys) {
            json_object_clear(sys);
            json_decref(sys);
        }

        if(pkg) {
            json_array_clear(pkg);
            json_decref(pkg);
        }
    }
}

extern char *get_json_sys()
{
    if(NULL == sys) build_sys_info();
    return json_dumps(sys, ENC_FLAGS);
}

extern char *get_json_pkg()
{
    if(NULL == pkg) build_pkg_info();
    return json_dumps(pkg, ENC_FLAGS);
}

extern char *get_json_root()
{
    if(! root)
    {
        root = json_object();

        char *myid = uuid();
        json_object_set_new(root, "uuid", json_string(myid));
        free(myid);

        free(get_json_sys());
        free(get_json_pkg());

        json_object_set_new(root, "sys", sys);
        json_object_set_new(root, "pkg", pkg);
    }

    return json_dumps(root, ENC_FLAGS);
}
